# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.3.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation as windows_foundation
import winrt.windows.foundation.collections as windows_foundation_collections
import winrt.windows.storage as windows_storage

from winrt.windows.media.playlists import PlaylistFormat

Self = typing.TypeVar('Self')

@typing.final
class Playlist_Static(type):
    def load_async(cls, file: typing.Optional[windows_storage.IStorageFile], /) -> windows_foundation.IAsyncOperation[Playlist]: ...

@typing.final
class Playlist(winrt.system.Object, metaclass=Playlist_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> Playlist: ...
    def __new__(cls: typing.Type[Playlist]) -> Playlist: ...
    @typing.overload
    def save_as_async(self, save_location: typing.Optional[windows_storage.IStorageFolder], desired_name: str, option: windows_storage.NameCollisionOption, /) -> windows_foundation.IAsyncOperation[windows_storage.StorageFile]: ...
    @typing.overload
    def save_as_async(self, save_location: typing.Optional[windows_storage.IStorageFolder], desired_name: str, option: windows_storage.NameCollisionOption, playlist_format: PlaylistFormat, /) -> windows_foundation.IAsyncOperation[windows_storage.StorageFile]: ...
    def save_async(self) -> windows_foundation.IAsyncAction: ...
    @_property
    def files(self) -> typing.Optional[windows_foundation_collections.IVector[windows_storage.StorageFile]]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.3.0

import enum

import winrt.system
from winrt import _winrt_windows_media_playlists

__all__ = [
    "PlaylistFormat",
    "Playlist",
]

class PlaylistFormat(enum.IntEnum):
    WINDOWS_MEDIA = 0
    ZUNE = 1
    M3U = 2

Playlist = _winrt_windows_media_playlists.Playlist
